@@ -1,4 +1,4 @@
-setMethod("asJSON", "logical", function(x, collapse = TRUE, na = c("null", "string", "NA"), ...) {
+setMethod("asJSON", "logical", function(x, collapse = TRUE, na = c("null", "string", "NA"), auto_unbox = FALSE, ...) {
   # validate arg
   na <- match.arg(na)
   
@@ -18,6 +18,10 @@ setMethod("asJSON", "logical", function(x, collapse = TRUE, na = c("null", "stri
     tmp <- as.character(tmp);
   }
   
+  if(isTRUE(auto_unbox) && length(tmp) == 1){
+    return(tmp);
+  }  
+  
   # collapse it
   if(collapse) {
     collapse(tmp)
