@@ -5,22 +5,24 @@
 #' @name prettify, minify
 #' @aliases minify prettify
 #' @export prettify minify
-#' @param txt JSON string
+#' @param txt \code{JSON} string
 #' @examples myjson <- toJSON(cars)
 #' cat(myjson)
-#' cat(prettify(myjson))
-#' cat(minify(myjson))
+#' prettify(myjson)
+#' minify(myjson)
 prettify <- function(txt) {
   txt <- paste(as.character(txt), collapse = "\n")
   enc <- mapEncoding(Encoding(txt))
-  .Call("R_jsonPrettyPrint", txt, enc)
+  ans <- .Call("R_jsonPrettyPrint", txt, enc)
+  structure(ans, class="json")
 } 
 
 #' @rdname prettify
 minify <- function(txt) {
   txt <- paste(as.character(txt), collapse = "\n")
   enc <- mapEncoding(Encoding(txt))
-  .Call("R_jsonMiniPrint", txt, enc)
+  ans <- .Call("R_jsonMiniPrint", txt, enc)
+  structure(ans, class="json")
 }
 
 
